<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['yk_order_model'] = 'yandex_kassa/yk_order_model';

$config['enable_demo_mode'] = false;
$config['action'] = $config['enable_demo_mode'] ? 'https://demomoney.yandex.ru/eshop.xml' : 'https://money.yandex.ru/eshop.xml';
$config['shopId'] = $config['enable_demo_mode'] ? 'demo shopId' : 'production shopId';
$config['scId'] = $config['enable_demo_mode'] ? 'demo scId': 'production scId';
$config['ShopPassword'] = 'some password';

$config['success_page'] = '/order/success';
$config['fail_page'] = '/order/fail';