<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Description of yandex_kassa_site
 *
 * @author Igor Ratsun
 */
class yandex_kassa_site extends MX_Controller
{

    /**
     * 
     * @param array $options
     * array(
     *  'user_full_name' => 'Test user',
     *  'amount' => '10',
     *  'order_id' => 'some order id',
     *  'user_phone' => '79110001000',
     *  'user_email' => 'user1423@domain.com',
     * )
     * @return string
     */
    public function payform($options = array())
    {
        $content = $this->load->config('yandex_kassa/config', true);

        return $this->parser->parse('yandex_kassa/form', array_merge($content, $options), true);
    }

    public function test()
    {
        return $this->parser->parse('yandex_kassa/test', array(), true);
    }

}
