<form method="POST" action="<?= $action ?>">

    <input type="hidden" name="shopId" value="<?= $shopId ?>">
    <input type="hidden" name="scid" value="<?= $scId ?>">
    <input type="hidden" name="customerNumber" size="64" value="<?= $user_full_name ?>">
    <input type="hidden" name="sum" size="64" value="<?= $amount ?>">

    <?php if (!empty($order_id)) : ?>
        <input name="orderNumber" value="<?= $order_id ?>" type="hidden"/> 
    <?php endif; ?>
    <?php if (!empty($user_phone)) : ?>
        <input name="cps_phone" value="<?= $user_phone ?>" type="hidden"/> 
    <?php endif; ?>
    <?php if (!empty($user_email)) : ?>
        <input name="cps_email" value="<?= $user_email ?>" type="hidden"/>
    <?php endif; ?>

    <div>
        <?php if ($enable_demo_mode) : ?>
            <input name="paymentType" value="AC" type="radio" checked="checked" />С банковской карты<br/>
            <input name="paymentType" value="PC" type="radio" />Со счета в Яндекс.Деньгах (яндекс кошелек)
        <?php else : ?>
            <input name="paymentType" value="" type="radio" checked="checked" />Выбор платежного метода на стороне Яндекс.Кассы "Умный платеж"
        <?php endif; ?>
    </div>

        <input type=submit value="Оплатить" id="yandex_kassa_btn">
</form>