<form method="POST" action="https://demomoney.yandex.ru/eshop.xml">
    <!-- Если у вас боевой режим платежей, то замените action="https://money.yandex.ru/eshop.xml" -->

    <!-- ОБЯЗАТЕЛЬНАНЫЕ ПОЛЯ (все параметры яндекс.кассы регистрозависимые) -->
    <input type="hidden" name="shopId" value="70180">
    <input type="hidden" name="scid" value="540344">
    Идентификатор клиента:<br>
    <input type=text name="customerNumber" size="64" value="client007"><br><br> 
    Сумма (руб.):<br> 
    <input type=text name="sum" size="64" value="10"><br><br>

    <!-- customerNumber -- до 64 символов; идентификатор плательщика в ИС Контрагента.
    В качестве идентификатора может использоваться номер договора плательщика, логин плательщика и т.п.
    Возможна повторная оплата по одному и тому же идентификатору плательщика.
    
    sum -- сумма заказа в рублях.
    -->

    <!-- необязательные поля (все параметры яндекс.кассы регистрозависимые) -->   
    <input name="orderNumber" value="bulava_order777" type="hidden"/> 
    <input name="cps_phone" value="79110001000" type="hidden"/> 
    <input name="cps_email" value="user1423@domain.com" type="hidden"/>

    <!-- Внимание! Для тестирования в ДЕМО-среде доступны только два метода оплаты: тестовый Яндекс.Кошелек и Тестовая банковская карта
    -->
    Умный платеж, рекомендуемый яндекс.кассой (когда вы передаете paymentType с пустым значением):
    <br>
    <input name="paymentType" value="" type="radio" checked="checked" />Выбор платежного метода на стороне Яндекс.Кассы "Умный платеж"
    <br>
    <input type=submit value="Оплатить"><br> 
    <hr>
    Стандартный платеж (paymentType передается с указанием конкретного метода)<br/>
    <input name="paymentType" value="AC" type="radio" />С банковской карты<br/>
    <input name="paymentType" value="PC" type="radio" />Со счета в Яндекс.Деньгах (яндекс кошелек)<br/>

    <!--
    Если подключен метод repeatCardPayment, то в платежную форму можно добавить
    <input name="rebillingOn" value="true" type="hidden"/> 
    -->

    <!--
    Ниже перечислены доступные формы оплаты.
    Перечисленные методы оплаты могут быть доступны в боевой среде после подписания Договора.
    Какие именно методы доступны для вашего Договора, вы можете уточнить у своего персонального менеджера.
    
    AB - Альфа-Клик 
    AC - банковская карта
    GP - наличные через терминал
    MA - MasterPass
    MC - мобильная коммерция
    PB  -интернет-банк Промсвязьбанка
    PC - кошелек Яндекс.Денег
    SB - Сбербанк Онлайн
    WM - кошелек WebMoney
    WQ - Qiwi
    QP - Куппи.ру
    KV - КупиВкредит
    
    <input name="paymentType" value="GP" type="radio">Оплата по коду через терминал<br>
    <input name="paymentType" value="WM" type="radio">Оплата cо счета WebMoney<br>
    <input name="paymentType" value="AB" type="radio">Оплата через Альфа-Клик<br>
    <input name="paymentType" value="PB" type="radio">Оплата через Промсвязьбанк<br>
    <input name="paymentType" value="MA" type="radio">Оплата через MasterPass<br>
    <input name="paymentType" value="QW" type="radio">Оплата через Qiwi<br>
    <input name="paymentType" value="QP" type="radio">Куппи.ру<br>
    <input name="paymentType" value="KV" type="radio">КупиВкредит<br>
    
    Перечисление всех методов оплаты https://tech.yandex.ru/money/doc/payment-solution/reference/payment-type-codes-docpage/
    -->

    <br>
    <input type=submit value="Оплатить"><br> 
</form>
<hr />
Документация: <a href="https://money.yandex.ru/doc.xml?id=526537">https://money.yandex.ru/doc.xml?id=526537</a>